=========
Changelog
=========

Version 0.1.0
=============

- Implemented tcp, udp and rtu modbus server
- Implemented generating Context
- Implemented Task decorator
- Created examples of use of mbsim-core

Version 0.1.1
=============

- Tasks are initialised or decorated

Version 1.0.0
=============

- Added Client module
- Task now can run in another Thread by block=True key word argument
- Task can now accept functions and coroutine functions

Version 1.0.1
=============

- Added Deprecation warning for Task decorator to remove block argument.
- Fixed Clean exits of server and client
